package com.ruoyi.system.utils.dbsync.util;

import java.sql.SQLException;
import java.sql.Statement;
import java.sql.ResultSet;
import java.sql.Connection;

public class SqlUtil
{
    public static ResultSet executeSql(final Connection conn, final String sql) throws SQLException {
        final Statement stmt = conn.createStatement();
        stmt.setQueryTimeout(20);
        final ResultSet rs = stmt.executeQuery(sql);
        return rs;
    }
    
    public static void executeSqlWithTransaction(final Connection conn, final String sql) throws SQLException {
        conn.setAutoCommit(false);
        try (final Statement stmt = conn.createStatement()) {
            stmt.setQueryTimeout(30);
            stmt.executeUpdate(sql);
            conn.commit();
        }
        catch (final SQLException e) {
            conn.rollback();
            throw e;
        }
        finally {
            conn.setAutoCommit(true);
        }
    }
    
    public static void executeBatchSqlWithTransaction(final Connection conn, final String[] sqlStatements) throws SQLException {
        conn.setAutoCommit(false);
        try (final Statement stmt = conn.createStatement()) {
            stmt.setQueryTimeout(20);
            for (final String sql : sqlStatements) {
                stmt.addBatch(sql);
            }
            stmt.executeBatch();
            conn.commit();
        }
        catch (final SQLException e) {
            conn.rollback();
            throw e;
        }
        finally {
            conn.setAutoCommit(true);
        }
    }
    
    public static void ddl(final Connection conn, final String sql) {
        try {
            final Statement stmt = conn.createStatement();
            stmt.setQueryTimeout(200);
            stmt.execute(sql);
        }
        catch (final Exception e) {
            System.out.println("ddl fail");
            e.printStackTrace();
        }
    }
    
    public static String getDbString(final String s) {
        return "'" + s + "'";
    }
}
